@@ -8,7 +8,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 
 def format_code(source, summary_wrap_length=0):
@@ -37,18 +37,19 @@ def format_code(source, summary_wrap_length=0):
                  previous_line.endswith('\\\r'))):
             formatted += previous_line[len(previous_line.rstrip(' \t\n\r\\')):]
 
+        # Preserve spacing
         if start_row > last_row:
             last_column = 0
         if start_column > last_column:
-            formatted += (' ' * (start_column - last_column))
+            formatted += ' ' * (start_column - last_column)
 
         if (token_type == tokenize.STRING and
                 starts_with_triple(token_string) and
                 previous_token_type == tokenize.INDENT):
             formatted += format_docstring(
-                    previous_token_string,
-                    token_string,
-                    summary_wrap_length=summary_wrap_length)
+                previous_token_string,
+                token_string,
+                summary_wrap_length=summary_wrap_length)
         else:
             formatted += token_string
 
@@ -71,17 +72,17 @@ def starts_with_triple(string):
 def format_docstring(indentation, docstring, summary_wrap_length=0):
     """Return formatted version of docstring.
 
-    Wrap summary lines if summary_wrap_length is greather than 0.
+    Wrap summary lines if summary_wrap_length is greater than 0.
 
     Relevant parts of PEP 257:
-    * For consistency, always use triple double quotes around docstrings.
-    * Triple quotes are used even though the string fits on one line.
-    * Multi-line docstrings consist of a summary line just like a one-line
-      docstring, followed by a blank line, followed by a more elaborate
-      description.
-    * The BDFL recommends inserting a blank line between the last paragraph
-      in a multi-line docstring and its closing quotes, placing the closing
-      quotes on a line by themselves.
+        - For consistency, always use triple double quotes around docstrings.
+        - Triple quotes are used even though the string fits on one line.
+        - Multi-line docstrings consist of a summary line just like a one-line
+          docstring, followed by a blank line, followed by a more elaborate
+          description.
+        - The BDFL recommends inserting a blank line between the last paragraph
+          in a multi-line docstring and its closing quotes, placing the closing
+          quotes on a line by themselves.
 
     """
     contents = strip_docstring(docstring)
@@ -148,18 +149,21 @@ def normalize_summary(summary, wrap_length=0):
     summary = re.sub('\s*\n\s*', ' ', summary.strip())
 
     # Add period at end of sentence
-    if summary and not summary.endswith('.'):
+    if summary and summary[-1].isalnum():
         summary += '.'
 
+    # This is disabled by default since it goes against PEP 257
     if wrap_length > 0:
         import textwrap
-        summary = '\n'.join(textwrap.wrap(summary, width=wrap_length))
+        # Compensate for triple quotes by temporarily prepending 3 spaces
+        summary = '\n'.join(textwrap.wrap(' ' * 3 + summary,
+                                          width=wrap_length)).strip()
 
     return summary
 
 
 def open_with_encoding(filename, encoding, mode='r'):
-    """Open file with a specific encoding."""
+    """Open and return a file with a specific encoding."""
     try:
         # Python 3
         return open(filename, mode=mode, encoding=encoding)
@@ -180,33 +184,34 @@ def detect_encoding(filename):
 def main(argv, standard_out):
     """Main entry point."""
     import argparse
-    parser = argparse.ArgumentParser(description=__doc__)
+    parser = argparse.ArgumentParser(description=__doc__, prog=argv[0])
     parser.add_argument('--in-place', action='store_true',
-                        help='make changes to file instead of printing diff')
+                        help='make changes to files instead of printing diffs')
     parser.add_argument('--no-backup', dest='backup', action='store_false',
                         help='do not write backup files')
-    parser.add_argument('--wrap-long-summaries', default=0, type=int,
-                        help='wrap long summary lines at this length')
+    parser.add_argument(
+        '--wrap-long-summaries', default=0, type=int, metavar='LENGTH',
+        help='wrap long summary lines at this length (default: 0)')
     parser.add_argument('--version', action='version', version=__version__)
     parser.add_argument('files', nargs='+',
                         help='files to format')
 
-    args = parser.parse_args(argv)
+    args = parser.parse_args(argv[1:])
 
     for filename in args.files:
         encoding = detect_encoding(filename)
         with open_with_encoding(filename, encoding=encoding) as input_file:
             source = input_file.read()
             formatted_source = format_code(
-                    source,
-                    summary_wrap_length=args.wrap_long_summaries)
+                source,
+                summary_wrap_length=args.wrap_long_summaries)
 
         if source != formatted_source:
             if args.in_place:
                 # Write output files with same encoding as input
                 if args.backup:
                     with open_with_encoding(filename + '.backup', mode='w',
-                            encoding=encoding) as backup_file:
+                                            encoding=encoding) as backup_file:
                         backup_file.write(source)
 
                 with open_with_encoding(filename, mode='w',
@@ -215,8 +220,8 @@ def main(argv, standard_out):
             else:
                 import difflib
                 diff = difflib.unified_diff(
-                        source.splitlines(True),
-                        formatted_source.splitlines(True),
-                        'before/' + filename,
-                        'after/' + filename)
+                    source.splitlines(True),
+                    formatted_source.splitlines(True),
+                    'before/' + filename,
+                    'after/' + filename)
                 standard_out.write(''.join(diff))
